@@ -1,5 +1,4 @@
 from django.utils.module_loading import import_string
-from delt.service.types import Service, ServiceType
 from django.conf import settings
 
 class DeltSettings:
@@ -16,20 +15,13 @@ class DeltSettings:
         self.dependencies = self.service_dict.get("DEPENDENCIES", [])
         self.name = self.service_dict.get("NAME")
         self.version = self.service_dict.get("VERSION", "0.1")
-        self.negotiate = import_string(self.service_dict.get("NEGOTIATE_HOOK"))
+        self.needs_negotiation = self.service_dict.get("NEEDS_NEGOTIATION", False)
         self.point_type = self.service_dict.get("POINT_TYPE", "graphql")
 
         self.register_installed = self.service_dict.get("REGISTER_INSTALLED", False)
 
 
 
-    @property
-    def service(self):
-        dc = self.service_dict
-        return Service(types=self.types, outward=self.outward, inward=self.inward, port=self.port, dependencies=self.dependencies, name=self.name, version=self.version)
-
-
-
 
 ACTIVE_DELT_SETTINGS = None
 
